export declare enum TimeIntervalLabel {
    SECONDS = "seconds",
    MINUTES = "minutes",
    HOURS = "hours",
    DAYS = "days",
    WEEKS = "weeks",
    MONTHS = "months",
    YEARS = "years"
}
export declare class ShleemyInterval {
    readonly first: Date;
    readonly toDate: Date;
    readonly rounding: "ceil" | "floor";
    private readonly humanReadable?;
    readonly diff: number;
    readonly tense: "future" | "past" | "present";
    constructor(first: Date, toDate: Date, rounding?: "ceil" | "floor", humanReadable?: {
        future?: (value: number, interval: TimeIntervalLabel) => string;
        past?: (value: number, interval: TimeIntervalLabel) => string;
    });
    get seconds(): number;
    get roundedSeconds(): number;
    get minutes(): number;
    get roundedMinutes(): number;
    get hours(): number;
    get roundedHours(): number;
    get days(): number;
    get roundedDays(): number;
    get weeks(): number;
    get roundedWeeks(): number;
    get months(): number;
    get roundedMonths(): number;
    get years(): number;
    get roundedYears(): number;
    get nearestInterval(): TimeIntervalLabel;
    static pluralInterval: (value: number, interval: TimeIntervalLabel) => string;
    private toFutureHumanReadable;
    private toPastHumanReadable;
    get forHumans(): string;
    toString(): string;
}
/**
 * Factory to build ShleemyInterval
 * @param date
 * @param options
 */
export declare const shleemy: (date: string | Date, options?: {
    toDate?: Date | string;
    rounding?: "ceil" | "floor";
    humanReadable?: {
        future?: (value: number, interval: TimeIntervalLabel) => string;
        past?: (value: number, interval: TimeIntervalLabel) => string;
    };
}) => ShleemyInterval;
