"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shleemy = exports.ShleemyInterval = exports.TimeIntervalLabel = void 0;
var TimeIntervalLabel;
(function (TimeIntervalLabel) {
    TimeIntervalLabel["SECONDS"] = "seconds";
    TimeIntervalLabel["MINUTES"] = "minutes";
    TimeIntervalLabel["HOURS"] = "hours";
    TimeIntervalLabel["DAYS"] = "days";
    TimeIntervalLabel["WEEKS"] = "weeks";
    TimeIntervalLabel["MONTHS"] = "months";
    TimeIntervalLabel["YEARS"] = "years";
})(TimeIntervalLabel = exports.TimeIntervalLabel || (exports.TimeIntervalLabel = {}));
var IntervalValues;
(function (IntervalValues) {
    IntervalValues[IntervalValues["MILLISECONDS"] = 1000] = "MILLISECONDS";
    IntervalValues[IntervalValues["SECONDS"] = 60] = "SECONDS";
    IntervalValues[IntervalValues["DAYS"] = 24] = "DAYS";
    IntervalValues[IntervalValues["WEEKS"] = 7] = "WEEKS";
    IntervalValues[IntervalValues["MONTHS"] = 30] = "MONTHS";
    IntervalValues[IntervalValues["YEARS"] = 365] = "YEARS";
})(IntervalValues || (IntervalValues = {}));
class ShleemyInterval {
    constructor(first, toDate, rounding = "floor", humanReadable) {
        this.first = first;
        this.toDate = toDate;
        this.rounding = rounding;
        this.humanReadable = humanReadable;
        this.toFutureHumanReadable = (value, interval) => this.humanReadable && this.humanReadable.future
            ? this.humanReadable.future(value, interval)
            : `in ${value === 1
                ? interval === TimeIntervalLabel.HOURS
                    ? "an"
                    : "a"
                : value} ${ShleemyInterval.pluralInterval(value, interval)}`;
        this.toPastHumanReadable = (value, interval) => this.humanReadable && this.humanReadable.past
            ? this.humanReadable.past(value, interval)
            : `${value === 1
                ? interval === TimeIntervalLabel.HOURS
                    ? "an"
                    : "a"
                : value} ${ShleemyInterval.pluralInterval(value, interval)} ago`;
        this.tense =
            first.getTime() < toDate.getTime()
                ? "past"
                : first.getTime() === toDate.getTime()
                    ? "present"
                    : "future";
        this.diff =
            this.tense === "future"
                ? Math.abs(first.getTime() - toDate.getTime())
                : Math.abs(first.getTime() - toDate.getTime());
    }
    get seconds() {
        return this.diff / IntervalValues.MILLISECONDS;
    }
    get roundedSeconds() {
        return Math[this.rounding](this.seconds);
    }
    get minutes() {
        return this.diff / (IntervalValues.MILLISECONDS * IntervalValues.SECONDS);
    }
    get roundedMinutes() {
        return Math[this.rounding](this.minutes);
    }
    get hours() {
        return (this.diff /
            (IntervalValues.MILLISECONDS *
                IntervalValues.SECONDS *
                IntervalValues.SECONDS));
    }
    get roundedHours() {
        return Math[this.rounding](this.hours);
    }
    get days() {
        return (this.diff /
            (IntervalValues.MILLISECONDS *
                IntervalValues.SECONDS *
                IntervalValues.SECONDS) /
            IntervalValues.DAYS);
    }
    get roundedDays() {
        return Math[this.rounding](this.days);
    }
    get weeks() {
        return (this.diff /
            (IntervalValues.MILLISECONDS *
                IntervalValues.SECONDS *
                IntervalValues.SECONDS) /
            IntervalValues.DAYS /
            IntervalValues.WEEKS);
    }
    get roundedWeeks() {
        return Math[this.rounding](this.weeks);
    }
    get months() {
        return (this.diff /
            (IntervalValues.MILLISECONDS *
                IntervalValues.SECONDS *
                IntervalValues.SECONDS) /
            IntervalValues.DAYS /
            IntervalValues.MONTHS);
    }
    get roundedMonths() {
        return Math[this.rounding](this.months);
    }
    get years() {
        return (this.diff /
            (IntervalValues.MILLISECONDS *
                IntervalValues.SECONDS *
                IntervalValues.SECONDS) /
            IntervalValues.DAYS /
            IntervalValues.YEARS);
    }
    get roundedYears() {
        return Math[this.rounding](this.years);
    }
    get nearestInterval() {
        let value;
        Object.values(TimeIntervalLabel).forEach(interval => {
            if (this[`rounded${interval[0].toUpperCase() + interval.substring(1)}`] > 0) {
                value = interval;
            }
        });
        return value;
    }
    get forHumans() {
        if (this.diff === 0 || this.tense === "present") {
            return "just now";
        }
        const fullIntervalName = this.nearestInterval;
        const value = this[`rounded${fullIntervalName[0].toUpperCase() + fullIntervalName.substring(1)}`];
        return this.tense === "future"
            ? this.toFutureHumanReadable(value, fullIntervalName)
            : this.toPastHumanReadable(value, fullIntervalName);
    }
    toString() {
        return this.forHumans;
    }
}
exports.ShleemyInterval = ShleemyInterval;
ShleemyInterval.pluralInterval = (value, interval) => value === 1 ? interval.substring(0, interval.length - 1) : interval;
const resolveDate = (date) => typeof date === "string" ? new Date(date) : date;
/**
 * Factory to build ShleemyInterval
 * @param date
 * @param options
 */
const shleemy = (date, options) => {
    return new ShleemyInterval(resolveDate(date), resolveDate((options === null || options === void 0 ? void 0 : options.toDate) || new Date()), options === null || options === void 0 ? void 0 : options.rounding, options === null || options === void 0 ? void 0 : options.humanReadable);
};
exports.shleemy = shleemy;
